@@ -6,7 +6,7 @@ from . import models
 
 MODIFIABLE_READ_ONLY_FIELDS = ['modified', 'created']
 TASK_EVENT_READ_ONLY_FIELDS = ['status', 'failure_reason']
-SPATIAL_ENTRY_EXCLUDE = ['footprint', 'outline']
+SPATIAL_ENTRY_EXCLUDE = ['footprint']
 
 
 class RelatedField(serializers.PrimaryKeyRelatedField):
@@ -47,6 +47,14 @@ class CollectionPermissionSerializer(serializers.ModelSerializer):
         fields = '__all__'
 
 
+class ChecksumFileFolderSerializer(serializers.Serializer):
+    known_size = serializers.IntegerField()
+    num_files = serializers.IntegerField()
+    num_url_files = serializers.IntegerField()
+    created = serializers.DateTimeField()
+    modified = serializers.DateTimeField()
+
+
 class ChecksumFileSerializer(serializers.ModelSerializer):
     """Serializer for ChecksumFiles.
 
@@ -71,36 +79,43 @@ class ChecksumFileSerializer(serializers.ModelSerializer):
         )
 
 
+class ChecksumFilePathQuerySerializer(serializers.Serializer):
+    path_prefix = serializers.CharField(required=False)
+
+
+class ChecksumFilePathsSerializer(serializers.Serializer):
+    folders = serializers.DictField(child=ChecksumFileFolderSerializer())
+    files = serializers.DictField(child=ChecksumFileSerializer())
+
+
 class SpatialEntrySerializer(serializers.ModelSerializer):
-    def to_representation(self, value):
-        ret = super().to_representation(value)
-        # NOTE: including footprint can cause the search results to blow up in size
-        ret['outline'] = json.loads(value.outline.geojson)
-        # NOTE HACK: this is dirty but it works
-        subentry = models.SpatialEntry.objects.filter(pk=value.pk).select_subclasses().first()
-        # Add hyperlink to get view for subtype if SpatialEntry
-        ret['subentry_type'] = type(subentry).__name__
-        try:
-            # TODO: enforce all sub models have name
-            ret['subentry_name'] = subentry.name
-        except AttributeError:
-            pass
-        return ret
+    outline = serializers.SerializerMethodField()
+    subentry_name = serializers.SerializerMethodField()
+    subentry_type = serializers.SerializerMethodField()
 
     class Meta:
         model = models.SpatialEntry
         exclude = SPATIAL_ENTRY_EXCLUDE
 
+    def get_outline(self, obj):
+        return json.loads(obj.outline.geojson)
+
+    def get_subentry_type(self, obj):
+        return type(obj).__name__
+
+    def get_subentry_name(self, obj):
+        return getattr(obj, 'name', None)
+
 
 class SpatialEntryFootprintSerializer(SpatialEntrySerializer):
-    def to_representation(self, value):
-        ret = super().to_representation(value)
-        ret['footprint'] = json.loads(value.footprint.geojson)
-        return ret
+    footprint = serializers.SerializerMethodField()
 
     class Meta:
         model = models.SpatialEntry
-        exclude = SPATIAL_ENTRY_EXCLUDE
+        fields = '__all__'
+
+    def get_footprint(self, obj):
+        return json.loads(obj.footprint.geojson)
 
 
 class SpatialAssetSerializer(SpatialEntrySerializer):
